import QtQuick 2.6
import QtQuick.Controls 2.0

ComboBox
{
    id:combobox_Control
    property alias combobox_Control: combobox_Control

    delegate: ItemDelegate {
        width: combobox_Control.width
        contentItem: Text
        {
            text: modelData
            color: "#21be2b"
            font: combobox_Control.font
            elide: Text.ElideRight
            verticalAlignment: Text.AlignVCenter
        }
        highlighted: combobox_Control.highlightedIndex == index
    }

    indicator: Canvas {
        id: canvas
        x: combobox_Control.width - width - combobox_Control.rightPadding
        y: combobox_Control.topPadding + (combobox_Control.availableHeight - height) / 2
        width: 12
        height: 8
        contextType: "2d"// causing crash on popUp..

        Connections {
            target: combobox_Control
            onPressedChanged: canvas.requestPaint()
        }

        onPaint: {
            context.reset();
            context.moveTo(0, 0);
            context.lineTo(width, 0);
            context.lineTo(width / 2, height);
            context.closePath();
            context.fillStyle = combobox_Control.pressed ? "#17a81a" : "#21be2b";
            context.fill();
        }
    }

    contentItem: Text {
        leftPadding: 0
        rightPadding: combobox_Control.indicator.width + combobox_Control.spacing

        text: combobox_Control.displayText
        font: combobox_Control.font
        color: combobox_Control.pressed ? "#17a81a" : "#21be2b"
        horizontalAlignment: Text.AlignLeft
        verticalAlignment: Text.AlignVCenter
        elide: Text.ElideRight
    }

    background: Rectangle {
        implicitWidth: 120
        implicitHeight: 40
        border.color: combobox_Control.pressed ? "#17a81a" : "#21be2b"
        border.width: combobox_Control.visualFocus ? 2 : 1
        radius: 2
    }

    popup: Popup {
        y: combobox_Control.height - 1
        width: combobox_Control.width
        implicitHeight: listview.contentHeight
        padding: 1

        contentItem: ListView {
            id: listview
            clip: true
            model: combobox_Control.popup.visible ? combobox_Control.delegateModel : null
            currentIndex: combobox_Control.highlightedIndex

            ScrollIndicator.vertical: ScrollIndicator { }
        }

        background: Rectangle {
            border.color: "#21be2b"
            radius: 2
        }
    }
}
