import QtQuick 2.6
import QtQuick.Controls 1.2
import QtQuick.Controls 2.0
import QtQuick.Layouts 1.3
import QtQuick.Dialogs 1.1
import QtQuick.Window 2.0
import "../RaspiComponents"
import "../js/RaspiReminderHelper.js" as RaspiReminderJavaScript
import ReminderModule 1.0

Popup
{
    id:popUp
    width: parent.width
    height: parent.height
    //modal:true
    focus: true
    closePolicy: Popup.CloseOnEscape | Popup.CloseOnPressOutsideParent
    property alias rectangle_ReminderPopUp: rectangle_ReminderPopUp
    property var reminderArray:ReminderProcessorListProvider.reminderProcessorList

    enter: Transition
    {
        NumberAnimation { property: "opacity"; from: 0.0; to: 1.0 }
    }

    background: Rectangle
    {
        implicitWidth: parent.width
        implicitHeight: parent.height
        border.color: "#444"
    }

    contentItem:Column
    {
        id:rectangle_ReminderPopUp
        width:parent.width
        height: parent.height
        property alias rectangle_ReminderRow: rectangle_ReminderRow

            Rectangle
            {
                id:rectangle_ReminderRow
                width:parent.width
                height: parent.height
                color: "light gray"
                property alias rectangle_SelectedReminderDetails: rectangle_SelectedReminderDetails
                property alias rectangle_ReminderLists: rectangle_ReminderLists
                property alias text_SelectedReminderDetails: text_SelectedReminderDetails
                property alias text_SelectedReminderStartTime: text_SelectedReminderStartTime
                property alias flick_PopUp: flick_PopUp
                property alias rectangle_SelectedReminderSnooze: rectangle_SelectedReminderSnooze

                Rectangle
                {
                    id:rectangle_SelectedReminderDetails
                    width:parent.width
                    height: parent.height*15/100
                    color: "light gray"
                    Text
                    {
                        id:text_SelectedReminderDetails
                        width:parent.width*80/100
                        height:parent.height*50/100
                        font.pointSize: 14
                    }
                    Text
                    {
                        id:text_SelectedReminderStartTime
                        width:parent.width*80/100
                        height:parent.height*30/100
                        font.pointSize: 14
                        anchors.top: text_SelectedReminderDetails.bottom
                    }
                }
                Rectangle
                {
                    id:rectangle_ReminderLists
                    width:parent.width
                    height: parent.height*60/100
                    border.width: 1
                    clip: true
                    Layout.fillWidth: true
                    Layout.preferredHeight: height
                    anchors.top:rectangle_SelectedReminderDetails.bottom

                    Flickable
                    {
                        id:flick_PopUp
                        clip: true
                        interactive: true
                        boundsBehavior: Flickable.StopAtBounds
                        width : parent.width
                        height: parent.height
                        contentWidth: parent.width
                        flickableDirection: Flickable.VerticalFlick
                        property var reminderContentArray:[]

                        ScrollBar.vertical: ScrollBar
                        {
                            id: scrollBar_Flickable
                            hoverEnabled:true
                            active:hovered || pressed
                            x:flick_PopUp.width-20
                        }
                    }
                }
            Rectangle
            {
                id:rectangle_SelectedRemindersActions
                width:parent.width
                height: parent.height*15/100
                color: "light gray"
                anchors.top:rectangle_ReminderLists.bottom
                Rectangle
                {
                    id:rectangle_DismissAll
                    width:parent.width*60/100
                    height: parent.height
                    color: "transparent"
                    RaspiButton
                    {
                        id:button_DismissAll
                        width: parent.width*50/100
                        height: parent.height*70/100
                        y:(parent.height-height)/2
                        text: qsTr("Dismiss All")
                        onClicked: RaspiReminderJavaScript.dismissAllItem(flick_PopUp.reminderContentArray,popUp)
                    }
                }
                Rectangle
                {
                    id:rectangle_OpenAndDismissItem
                    width:parent.width*40/100
                    height: parent.height
                    anchors.left: rectangle_DismissAll.right
                    color: "transparent"
                    RaspiButton
                    {
                        id:button_OpenItem
                        width: parent.width*45/100
                        height: parent.height*70/100
                        y:(parent.height-height)/2
                        text: qsTr("Open Item")
                    }
                    RaspiButton
                    {
                        id:button_DismissItem
                        width: parent.width*45/100
                        height: parent.height*70/100
                        y:(parent.height-height)/2
                        text: qsTr("Dismiss")
                        x:parent.width-(button_OpenItem.width+5)
                        onClicked:RaspiReminderJavaScript.dismissItem(flick_PopUp.reminderContentArray,popUp)
                    }
                }
            }
            Rectangle
            {
                id:rectangle_SelectedReminderSnooze
                width:parent.width
                height: parent.height*10/100
                color: "light gray"
                anchors.top:rectangle_SelectedRemindersActions.bottom

                Label
                {
                    id:label_Info
                    width: parent.width
                    height: parent.height*30/100
                    text: qsTr("Click Snooze to be reminded again in:")
                    elide: "ElideLeft"
                }
                Rectangle
                {
                    id:rectangle_SnoozeTime
                    width: parent.width*75/100
                    height: parent.height*60/100
                    anchors.top:label_Info.bottom

                    RaspiMainMenuComboBox
                    {
                        id:combobox_ReminderSnoozeInterval
                        width: parent.width
                        height: parent.height
                        currentIndex: 0
                        combobox_Control.model:
                        [
                            "5","10","15","20","30","60"
                        ]
                    }
                }
                Rectangle
                {
                    id:rectangle_SnoozeButton
                    width: parent.width*20/100
                    height: parent.height*60/100
                    x: (parent.width-width)
                    anchors.top:label_Info.bottom

                    RaspiButton
                    {
                        id:button_Snooze
                        width: parent.width
                        height: parent.height
                        text: qsTr("Snooze")
                        onClicked:RaspiReminderJavaScript.snoozeItem(flick_PopUp,popUp,combobox_ReminderSnoozeInterval.currentText)
                    }
                }
            }
        }
    }
}
